<?php

namespace App\Http\Controllers;

use App\Models\Material;
use App\Models\Supplier;
use Illuminate\Http\Request;

class MaterialController extends Controller
{

    public function index(Request $request)
{
    $suppliers = Supplier::all();

    $query = Material::with('supplier');

    if ($request->has('supplier_id') && !empty($request->supplier_id)) {
        $query->where('supplier_id', $request->supplier_id);
    }

    $materials = $query->paginate(9);

    return view('material.index', compact('materials', 'suppliers'));

}


    public function create()
    {
        $suppliers = Supplier::pluck('name', 'id')->toArray(); 
        return view('material.create', compact('suppliers'));
    }

    public function store(Request $request)
    {
        $validated = $request->validate([
            'supplier_id' => 'required|exists:supplier,id',  
            'Nom_Materiel' => 'required|string|max:255',
            'ref' => 'required|string|max:255',
            'unit' => 'required|string',
            'a_price' => 'required|numeric|min:0',  
             'photo' => 'nullable|image|mimes:jpeg,png,jpg,gif,svg|max:2048',
        ]);

        $data = [
            'supplier_id' => $request->supplier_id,
            'Nom_Materiel' => $request->Nom_Materiel,
            'ref' => $request->ref,
            'unit' => $request->unit,
            'a_price' => $request->a_price,
        ];
    
        if ($request->hasFile('photo')) {
            $photo = $request->file('photo');
            $photoName = time() . '.' . $photo->getClientOriginalExtension();
            $photoPath = $photo->storeAs('materials', $photoName, 'public');
            $data['photo'] = $photoPath; 
        }
    
        Material::create($data);

        return redirect()->route('material.index')->with('success', __('Material created successfully'));
    }


    public function show($id)
    {
        $material = Material::with('supplier')->findOrFail($id);
        return view('material.detail', compact('material'));
    }
    

    public function edit($id)
{
    $material = Material::findOrFail($id);
    $suppliers = Supplier::pluck('name', 'id')->toArray(); 
    return view('material.edit', compact('material', 'suppliers'));
}


public function update(Request $request, $id)
{
    $validated = $request->validate([
        'Nom_Materiel' => 'required|string|max:255',
        'ref' => 'required|string|max:255',
        'unit' => 'required|string',
        'a_price' => 'required|numeric',
        'supplier_id' => 'required|exists:supplier,id',
        'photo' => 'nullable|image|mimes:jpeg,png,jpg,gif|max:2048',
    ]);

    $material = Material::findOrFail($id);
    $material->update([
        'Nom_Materiel' => $request->Nom_Materiel,
        'ref' => $request->ref,
        'unit' => $request->unit,
        'a_price' => $request->a_price,
        'supplier_id' => $request->supplier_id,
    ]);

    if ($request->hasFile('photo')) {
        $photoPath = $request->photo->store('materials', 'public');
        $material->photo = $photoPath;
        $material->save();
    }

    return redirect()->route('material.index')->with('success', __('Material updated successfully'));

}

public function destroy($id)
{
    $material = Material::find($id);

    if (!$material) {
        return redirect()->route('material.index')->with('error', 'Material not found');
    }

    $material->delete();

    return redirect()->route('material.index')->with('success', 'Material deleted successfully');
}

}
