<?php
namespace App\Http\Controllers;

use Illuminate\Http\Request;
use App\Models\OrderCompagnie;
use App\Models\OrderCompagnieDetail;
use App\Models\Material;
use App\Models\Supplier;
use Carbon\Carbon;
use Illuminate\Support\Facades\DB;
use misterspelik\LaravelPdf\Facades\Pdf;


class OrderCompagnieController extends Controller {
    public function index() {
        $materials = Material::paginate(10);
    }
    public function addToOrder(Request $request)
{
    $validated = $request->validate([
        'material_id' => 'required|exists:materials,id',
        'quantity' => 'required|integer|min:1',
    ]);

    return DB::transaction(function () use ($validated) {
        $material = Material::findOrFail($validated['material_id']);

        $order = OrderCompagnie::where('user_id', auth()->id())
            ->where('supplier_id', $material->supplier_id)
            ->where('status', 'pending')
            ->first();

        if (!$order) {
            $order = OrderCompagnie::create([
                'user_id' => auth()->id(),
                'supplier_id' => $material->supplier_id,
                'status' => 'pending',
                'total_price' => 0
            ]);
        }

        $detail = OrderCompagnieDetail::where('order_id', $order->id)
            ->where('material_id', $material->id)
            ->first();

        if ($detail) {
            $detail->quantity += $validated['quantity'];
            $detail->unit_price = $material->a_price;
            $detail->subtotal = $detail->quantity * $material->a_price;
            $detail->save();
        } else {
            OrderCompagnieDetail::create([
                'order_id' => $order->id,
                'material_id' => $material->id,
                'quantity' => $validated['quantity'],
                'unit_price' => $material->a_price,
                'subtotal' => $validated['quantity'] * $material->a_price
            ]);
        }

        $order->calculateTotal();

        return back()->with('success', 'Produit ajouté à la commande.');
    });
}



 public function add(Request $request)
{
    $request->validate([
        'material_id' => 'required|exists:materials,id',
        'quantity' => 'required|integer|min:1',
    ]);

    $material = Material::findOrFail($request->material_id);

    $order = OrderCompagnie::firstOrCreate(
        ['user_id' => auth()->id(), 'status' => 'pending'],
        ['total_price' => 0]
    );

    $subtotal = $material->a_price * $request->quantity;
    
    OrderCompagnieDetail::create([
        'order_id' => $order->id, 
        'material_id' => $material->id,
        'quantity' => $request->quantity,
        'subtotal' => $subtotal,
    ]);

    $order->increment('total_price', $subtotal);

    return response()->json(['success' => 'Produit ajouté à la commande.']);
}


public function cart()
{
    $order = OrderCompagnie::with(['details' => function($query) {
            $query->with('material');
        }])
        ->where('user_id', auth()->id())
        ->where('status', 'pending')
        ->first();

    if ($order) {
        logger()->debug('Order found', [
            'id' => $order->id,
            'details_count' => $order->details->count(),
            'user_id' => auth()->id()
        ]);
    } else {
        logger()->debug('No order found for user', ['user_id' => auth()->id()]);
    }

    return view('order_compagnie.index', [
        'order' => $order,
        'orderDetails' => $order ? $order->details : collect(),
        'total' => $order ? $order->total_price : 0
    ]);
}
public function validateOrder($id)
{
    $order = OrderCompagnie::findOrFail($id);
    
    $order->status = 'validated';
    $order->validated_at = now();  
    $order->user_id = auth()->id();
    $order->save();

    return redirect()->back()->with('success', 'Commande validée.');
}

public function showDetails($id)
{
    $order = OrderCompagnie::with(['details.material', 'supplier', 'user'])->findOrFail($id);

    return view('order_compagnie.show', compact('order'));
}

public function updateStatus(Request $request, $id)
{
    $request->validate([
        'status' => 'required|in:pending,validated,cancel',
    ]);

    $order = OrderCompagnie::findOrFail($id);

    if (in_array($request->status, ['validated', 'cancel'])) {
        $order->validated_at = now();  
    }

    $order->status = $request->input('status');
    
    $order->save();

    return redirect()->back()->with('success', 'Commande validée.');
}
public function generatePDF($orderId)
    {
        $order = OrderCompagnie::find($orderId);

        if (!$order) {
            return redirect()->route('orderCompagnie.index')->with('error', 'Order not found');
        }

        $pdf = Pdf::loadView('orders.pdf', ['order' => $order]);
        return $pdf->download('commande.pdf');
    }



}
