<?php

namespace App\Http\Controllers;

use Illuminate\Http\Request;
use App\Models\OrderCompagnie;
use App\Models\OrderCompagnieDetail;
use App\Models\Material;
use App\Models\Supplier;
use Carbon\Carbon;
use Illuminate\Support\Facades\DB;


class OrderCompagnieDetailController extends Controller
{
    public function index(Request $request)
    {
        $query = OrderCompagnie::with(['supplier', 'details', 'user' => function($query) {
            $query->select('id', 'name', 'email'); 
        }]);
    
        if ($request->filled('status') && $request->status == 'pending') {
            $query->where('status', 'pending');
        }
    
        $orders = $query->orderBy('created_at', 'desc')->paginate(10);
    
        return view('order_compagnie.index', compact('orders'));
    }
    

    public function show($id)
    {
        $order = OrderCompagnie::with('details.material')->findOrFail($id); 
    
        return view('orders.show', compact('order'));
    }
    
public function validateOrder($id)
{
    $order = OrderCompagnie::findOrFail($id);
    $order->status = 'validated';
    $order->validated_at = now(); 
    $order->user_id = auth()->id(); 
    $order->save();

    return redirect()->back()->with('success', 'Commande validée.');
}


public function destroy($id)
{
    $detail = OrderCompagnieDetail::findOrFail($id);
    $orderId = $detail->order_id;  

    $detail->delete();

    return redirect()->route('orders.details', $orderId)->with('success', 'Produit supprimé avec succès');
}
public function updateQuantity(Request $request, $id)
{
    $request->validate([
        'quantity' => 'required|integer|min:1', 
    ]);

    $detail = OrderCompagnieDetail::findOrFail($id);
    $detail->quantity = $request->quantity;

    $detail->subtotal = $detail->quantity * $detail->unit_price;
    
    $detail->save();

    return redirect()->route('orders.details', $detail->order_id)->with('success', 'Quantité mise à jour avec succès');
}

}