<?php

namespace App\Models;

use Illuminate\Database\Eloquent\Model;
use Illuminate\Database\Eloquent\Relations\BelongsTo;
use Illuminate\Database\Eloquent\Relations\HasMany;
use Barryvdh\DomPDF\Facade as PDF;



class OrderCompagnie extends Model
{
    protected $table = 'order_compagnie'; 
    protected $attributes = [
        'status' => 'pending'
    ];
    protected $casts = [
        'validated_at' => 'datetime',
    ];
    protected $fillable = [
        'supplier_id',  
        'total_price',
        'status',
        'validated_at' => 'datetime',
        'user_id',
    ];
    public function supplier(): BelongsTo
    {
        return $this->belongsTo(Supplier::class);
    }
    
  
    public function details(): HasMany
    {
        return $this->hasMany(OrderCompagnieDetail::class, 'order_id');
    }
    
    public function calculateTotal(): void
    {
        $this->total_price = $this->details->sum('subtotal');
        $this->save();
    }
public function getFormattedValidatedAtAttribute()
{
    return $this->validated_at 
        ? $this->validated_at->format('d/m/Y H:i') 
        : '-';
}

public function user()
{
    return $this->belongsTo(User::class);
}

public function generatePDF($id)
{
    $order = OrderCompagnie::with(['supplier', 'details'])->findOrFail($id);
    
    $pdf = PDF::loadView('order_compagnie.pdf', compact('order'));
    return $pdf->download('commande_' . $order->id . '.pdf');
}

}