<?php

namespace App\Models;

use Illuminate\Database\Eloquent\Model;
use Illuminate\Database\Eloquent\Relations\BelongsTo;
use Illuminate\Database\Query\Expression;
use NumberFormatter;

class OrderCompagnieDetail extends Model
{
    protected $table = 'order_compagnie_details';
    
    protected $fillable = [
        'order_id',
        'material_id',
        'quantity',
        'unit_price',
        'subtotal'
    ];
    
    
    protected $appends = ['formatted_subtotal'];
    
    public function order(): BelongsTo
    {
        return $this->belongsTo(OrderCompagnie::class);
    }
    
    public function material()
    {
        return $this->belongsTo(Material::class, 'material_id');
    }
    
    
    protected static function booted()
{
    static::saving(function (self $detail) {
        if (!($detail->quantity instanceof Expression) && !($detail->unit_price instanceof Expression)) {
            $detail->calculateSubtotal();
        }
    });
}

    
    
    public function calculateSubtotal(): void
{
    $quantity = $this->quantity instanceof Expression
        ? (int) $this->getRawOriginal('quantity')
        : (int) $this->quantity;

    $unitPrice = $this->unit_price instanceof Expression
        ? (float) $this->getRawOriginal('unit_price')
        : (float) $this->unit_price;

    $this->subtotal = round($quantity * $unitPrice, 2);
}



    
    public function getFormattedSubtotalAttribute(): string
    {
        $formatter = new NumberFormatter(app()->getLocale(), NumberFormatter::CURRENCY);
        return $formatter->formatCurrency($this->subtotal, config('app.currency'));
    }
}