@extends('layouts.admin')

@section('page-title')
    {{__('Manage Materials')}}
@endsection

@section('breadcrumb')
    <li class="breadcrumb-item"><a href="{{route('dashboard')}}">{{__('Dashboard')}}</a></li>
    <li class="breadcrumb-item">{{__('Materials')}}</li>
@endsection

@section('action-btn')
    <div class="float-end">
        <a href="#" data-size="md"  data-bs-toggle="tooltip" title="{{__('Import')}}" data-url="{{ route('productservice.file.import') }}" data-ajax-popup="true" data-title="{{__('Import product CSV file')}}" class="btn btn-sm bg-brown-subtitle me-1">
            <i class="ti ti-file-import"></i>
        </a>
        <a href="{{route('productservice.export')}}" data-bs-toggle="tooltip" title="{{__('Export')}}" class="btn btn-sm btn-secondary me-1">
            <i class="ti ti-file-export"></i>
        </a>

        <a href="#" data-size="lg" data-url="{{ route('material.create') }}" data-ajax-popup="true" data-bs-toggle="tooltip" data-bs-original-title="{{__('Create')}}" data-title="{{__('Create New Product & Service')}}" class="btn btn-sm btn-primary">
            <i class="ti ti-plus"></i>
        </a>
    </div>
@endsection

@section('content')
<div class="my-3 d-flex justify-content-end">
    <a href="{{ route('admin.orders.index') }}" class="btn btn-success me-2">Voir Produits Commandés</a>
</div>
<div class="mb-3 d-flex justify-content-end">
    <form action="{{ route('material.index') }}" method="GET" class="d-flex align-items-center">
        <select name="supplier_id" id="supplier_filter" class="form-select me-2" onchange="this.form.submit()">
            <option value="">{{ __('Tous les fournisseurs') }}</option>
            @foreach($suppliers as $supplier)
                <option value="{{ $supplier->id }}" {{ request('supplier_id') == $supplier->id ? 'selected' : '' }}>
                    {{ $supplier->name }}
                </option>
            @endforeach
        </select>
    </form>
</div>

    <div class="row row-cols-1 row-cols-sm-2 row-cols-md-3 g-4">
        @foreach($materials as $material)
            <div class="col">
                <div class="card h-100 shadow-sm border-0 rounded-lg overflow-hidden">
                    <!-- Affichage de la photo en haut, taille d'image uniforme -->
                    <img src="{{ asset('storage/' . $material->photo) }}" class="card-img-top img-fluid" alt="{{ $material->Nom_Materiel }}" 
                         style="object-fit: cover; width: 100%; height: 200px;" 
                         data-bs-toggle="tooltip" data-bs-placement="top" title="Référence : {{ $material->ref }} - Fournisseur : {{ $material->supplier->name }}">

                    <div class="card-body d-flex flex-column">
                        <!-- Nom du matériel -->
                        <h5 class="card-title text-truncate" 
                            data-bs-toggle="tooltip" data-bs-placement="top" 
                            title="Référence : {{ $material->ref }} - Fournisseur : {{ $material->supplier->name }}">
                            {{ $material->Nom_Materiel }}
                        </h5>

                        <!-- Prix unitaire -->
                        <p class="card-text text-muted">Prix Unitaire : {{ number_format($material->a_price, 2) }} MAD</p>

                        <!-- Formulaire pour choisir la quantité et le bouton dans la même ligne -->
                        <div class="d-flex w-100 align-items-bottom">
                            <form action="{{ route('orderCompagnie.add') }}" method="POST" class="w-100 d-flex align-items-bottom">
                                @csrf
                                <!-- Input pour choisir la quantité -->
                                <div class="mb-3 me-2" style="flex: 1;">
                                    <input type="number" class="form-control" id="quantity_{{ $material->id }}" name="quantity" min="1" value="1" style="height: 38px;">
                                </div>
                            
                                <!-- Champ caché pour envoyer l'ID du matériel -->
                                <input type="hidden" name="material_id" value="{{ $material->id }}">
                            
                                <!-- Bouton "Commander" -->
                                <button type="submit" class="btn btn-sm btn-success" data-bs-toggle="tooltip" title="{{__('Order')}}" style="height: 38px; display: flex; align-items: center; justify-content: center; flex: 1;">
                                    <i class="ti ti-shopping-cart text-white"></i> {{__('Commander')}}
                                </button>
                            </form>
                            
                            
                        </div>
                        
                        
                        
                        
                        
                        <!-- Autres actions (détails, édition, suppression) centrées sous la ligne de commande -->
                        <div class="d-flex justify-content-center mt-2">
                            @if(Gate::check('edit product & service') || Gate::check('delete product & service'))
                                <div class="action-btn me-2">
                                    <a href="#" class="mx-3 btn btn-sm align-items-center bg-warning" data-url="{{ route('material.detail', $material->id) }}" data-ajax-popup="true" data-bs-toggle="tooltip" title="{{__('Warehouse Details')}}" data-title="{{__('Warehouse Details')}}">
                                        <i class="ti ti-eye text-white"></i>
                                    </a>
                                </div>
                                
                                @can('edit product & service')
                                <div class="action-btn me-2">
                                    <a href="#" class="mx-3 btn btn-sm align-items-center bg-info" data-url="{{ route('material.edit', $material->id) }}" data-ajax-popup="true" data-size="lg" data-bs-toggle="tooltip" title="{{__('Edit')}}" data-title="{{__('Edit Product')}}">
                                        <i class="ti ti-pencil text-white"></i>
                                    </a>
                                </div>
                                @endcan
                        
                                @can('delete product & service')
                                <div class="action-btn">
                                    {!! Form::open(['method' => 'DELETE', 'route' => ['material.destroy', $material->id], 'id' => 'delete-form-' . $material->id]) !!}
                                    <a href="#" class="mx-3 btn btn-sm align-items-center bg-danger" data-bs-toggle="tooltip" title="{{__('Delete')}}"><i class="ti ti-trash text-white"></i></a>
                                    {!! Form::close() !!}
                                </div>
                                @endcan
                            @endif
                        </div>
                        
                    </div>
                </div>
            </div>
        @endforeach
    </div>

    <!-- Pagination -->
    <div class="d-flex justify-content-center mt-4">
        {{ $materials->links() }}
    </div>
@endsection

<script>
    // synchroniser les inputs
    document.addEventListener("DOMContentLoaded", () => {
        @foreach($materials as $material)
            document.getElementById("quantity_{{ $material->id }}").addEventListener("input", function () {
                document.getElementById("form_quantity_{{ $material->id }}").value = this.value;
            });
        @endforeach
    });
</script>
