@extends('layouts.admin')

@section('content')
<div class="container-fluid">
    <div class="card shadow mb-4">
        <div class="card-header py-3 d-flex justify-content-between align-items-center">
            <h6 class="m-0 font-weight-bold text-primary">Liste des Commandes</h6>
            <div class="d-flex justify-content-between align-items-center">
                <!-- Formulaire de filtrage -->
                <form action="{{ route('admin.orders.index') }}" method="GET" class="d-flex">
                    <select name="status" class="form-control form-control-sm" style="width: 150px;">
                        <option value="">Tous les statuts</option>
                        <option value="pending" {{ request('status') == 'pending' ? 'selected' : '' }}>Pending</option>
                        <option value="validated" {{ request('status') == 'validated' ? 'selected' : '' }}>Validated</option>
                        <option value="cancel" {{ request('status') == 'cancel' ? 'selected' : '' }}>Cancel</option>
                    </select>
                    <button type="submit" class="btn btn-primary btn-sm ml-2 ml-2">
                        <i class="fas fa-filter"></i>
                    </button>
                </form>
            
                <!-- Bouton Exporter -->
                <a href="#" class="btn btn-sm btn-secondary" style="margin-left: 10px">
                    <i class="fas fa-file-export"></i> Exporter
                </a>
            </div>
            
        </div>
        
        <div class="card-body">
            <div class="table-responsive">
                <table class="table table-bordered table-hover">
                    <thead class="thead-light">
                        <tr>
                            <th>ID</th>
                            <th>Fournisseur</th>
                            <th>Total</th>
                            <th>Date Validation</th>
                            <th>Action</th>
                            <th>Validée/Annulée par</th>
                            <th>Details</th>

                        </tr>
                    </thead>
                    <tbody>
                        @foreach($orders as $order)
                        <tr>
                            <td>{{ $order->id }}</td>
                            <td>{{ $order->supplier->name }}</td>
                            <td>{{ number_format($order->total_price, 2) }} MAD</td>
                            <td>
                                @if($order->status === 'validated' || $order->status === 'cancel')
                                    @if($order->validated_at)
                                        {{ $order->validated_at->format('d/m/Y H:i') }}
                                    @else
                                        - 
                                    @endif
                                @else
                                    - 
                                @endif
                            </td>
                            
                            
                            <td>
                                <form action="{{ route('orders.updateStatus', $order->id) }}" method="POST" class="d-inline">
                                    @csrf
                                    @method('PUT')
                                    <select name="status" class="form-control form-control-sm" style="width: 150px;" onchange="this.form.submit()" id="statusSelect-{{ $order->id }}">
                                        <option value="pending" {{ $order->status == 'pending' ? 'selected' : '' }} style="color:yellow">Pending</option>
                                        <option value="validated" {{ $order->status == 'validated' ? 'selected' : '' }} style="color:green">Validated</option>
                                        <option value="cancel" {{ $order->status == 'cancel' ? 'selected' : '' }} style="color:red">Cancel</option>
                                    </select>
                                </form>
                            </td>
                            
                            
                            <td>
                                @if($order->status === 'validated' || $order->status === 'cancel' && $order->user) 
                                    <span class="font-weight-bold">{{ $order->user->name }}</span>
                                    <small class="text-muted d-block">{{ $order->user->email }}</small>
                                @else
                                    -
                                @endif
                            </td>
                            <td>
                                <a href="{{ route('orders.details', $order->id) }}" class="btn btn-sm btn-info">
                                    <i class="fas fa-eye"></i> Voir les produits
                                </a>
                                
                                
                            </td>
                            
                        </tr>
                        @endforeach
                    </tbody>
                </table>
            </div>
            
            <div class="mt-4 d-flex justify-content-center">
                {{ $orders->links() }}
            </div>
        </div>
    </div>
</div>
@endsection



