@extends('layouts.admin')

@section('content')
<div class="container">
    <h3 class="my-4 text-primary">Détails de la Commande #{{ $order->id }}</h3>

    <div class="mb-3">
        @dump($order)
        <strong>Fournisseur :</strong> <span class="text-muted">{{ $order->supplier->name }}</span><br>
        <strong>Total :</strong> <span class="font-weight-bold">{{ number_format($order->total_price, 2) }} MAD</span><br>
        <strong>Status :</strong> {{ $order->status }}<br>
        <strong>Validé par :</strong> {{ $order->user ? $order->user->name : '-' }}<br>
        <strong>Dernière validation/Annulation :</strong> {{ $order->validated_at ? $order->validated_at->format('d/m/Y H:i') : '-' }}<br>
    </div>

    <h5 class="my-4">Produits :</h5>
    <table class="table table-striped table-bordered">
        <thead class="thead-light">
            <tr>
                <th>Matériel</th>
                <th>Quantité</th>
                <th>Prix Unitaire</th>
                <th>Sous-total</th>
                <th>Action</th>
            </tr>
        </thead>
        <tbody>
            @foreach($order->details as $detail)
            <tr>
                <td>{{ $detail->material->Nom_Materiel ?? 'Matériel supprimé' }}</td>
                <td>
                    <form action="{{ route('order-details.update-quantity', $detail->id) }}" method="POST" class="d-inline">
                        @csrf
                        @method('PUT')
                        <div class="input-group">
                            <input type="number" name="quantity" value="{{ $detail->quantity }}" min="1" class="form-control form-control-sm" style="width: 10px; margin-right:10px;">
                            <div class="input-group-append">
                                <button type="submit" class="btn btn-sm btn-warning">
                                    <i class="fas fa-edit"></i> Modifier
                                </button>
                            </div>
                        </div>
                    </form>
                </td>
                <td>{{ number_format($detail->unit_price, 2) }} MAD</td>
                <td>{{ number_format($detail->subtotal, 2) }} MAD</td>
                <td>
                    <form action="{{ route('order-details.destroy', $detail->id) }}" method="POST" class="d-inline" onsubmit="return confirm('Êtes-vous sûr de vouloir supprimer ce produit ?')">
                        @csrf
                        @method('DELETE')
                        <button type="submit" class="btn btn-sm btn-danger" data-toggle="tooltip" data-placement="top" title="Supprimer ce produit">
                            <i class="fas fa-trash-alt"></i>
                        </button>
                    </form>
                </td>
            </tr>
            @endforeach
        </tbody>
    </table>
    <div class="mb-3">
        <form action="{{ route('admin.orders.updateStatus', $order->id) }}" method="POST" class="d-inline">
            @csrf
            @method('PUT')
            <input type="hidden" name="status" value="validated">
            <button type="submit" class="btn btn-sm btn-success">
                <i class="fas fa-check-circle"></i> Valider la commande
            </button>
        </form>
    
        <!-- Bouton pour générer le PDF -->
        <a href="{{ route('admin.orders.generatePDF', $order->id) }}" class="btn btn-sm btn-danger ml-2">
            <i class="fas fa-file-pdf"></i> Générer PDF
        </a>
    </div>
    
    <a href="{{ route('admin.orders.index') }}" class="btn btn-secondary mt-3">
        <i class="fas fa-arrow-left"></i> Retour à la liste
    </a>
</div>

@endsection

@section('scripts')
    <script>
        // Initialisation des tooltips Bootstrap
        $(function () {
            $('[data-toggle="tooltip"]').tooltip();
        });
    </script>
@endsection
